@@ -2,19 +2,20 @@
 ##
 ##  Call 'rcmdcheck' on a package
 ##
-##  Copyright (C) 2016         Dirk Eddelbuettel
+##  Copyright (C) 2016 - 2017  Dirk Eddelbuettel
 ##
 ##  Released under GPL (>= 2)
 
 suppressMessages(library(docopt))       # we need docopt (>= 0.3) as on CRAN
 
 ## configuration for docopt
-doc <- "Usage: rcc.r [-h] [-x] [-c] [-q] [--args ARGS] [--libpath LIBP] [--repos REPO] [PATH...]
+doc <- "Usage: rcc.r [-h] [-x] [-c] [-f] [-q] [--args ARGS] [--libpath LIBP] [--repos REPO] [PATH...]
 
 -c --as-cran          should '--as-cran' be added to ARGS [default: FALSE]
 -a --args ARGS        additional arguments to be passed to 'R CMD CHECK' [default: ]
 -l --libpath LIBP     additional library path to be used by 'R CMD CHECK' [default: ]
 -r --repos REPO       additional repositories to be used by 'R CMD CHECK' [default: ]
+-f --fast             should vignettes and manuals be skipped [default: FALSE]
 -q --quiet            should 'rcmdcheck' be called qietly [default: FALSE]
 -h --help             show this help text
 -x --usage            show help and short example usage"
@@ -43,6 +44,9 @@ if (opt$args == "") {                   # special treatment for --args and -c
         opt$args <- c(opt$args, "--as-cran")
     }
 }
+if (opt$fast) {
+    opt$args <- c(opt$args, "--ignore-vignettes --no-manual")
+}
 
 if (length(opt$PATH) == 0) opt$PATH <- "." 		# default argument current directory
 if (opt$libpath == "") opt$libpath <- .libPaths()	# default library pathr
